@@ -332,12 +332,12 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             raise
 
     def add_related_document_to_family(self, document_family_id: str, transition: DocumentTransition,
-                                       document: Document):
+                                       document: Document) -> ContentObject:
         from kodexa import KodexaPlatform
         try:
             logger.info(f"Putting document to family id {document_family_id}")
 
-            data = {'transitionType': str(transition.transition_type),
+            data = {'transitionType': transition.transition_type.value,
                     'sourceContentObjectId': transition.source_content_object_id}
             files = {"document": document.to_msgpack()}
             document_family_response = requests.post(
@@ -347,7 +347,7 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
                 files=files)
 
             if document_family_response.status_code == 200:
-                return DocumentFamily.from_dict(document_family_response.json())
+                return ContentObject.from_dict(document_family_response.json())
             else:
                 msg = "Document family create failed [" + document_family_response.text + "], response " + str(
                     document_family_response.status_code)
@@ -412,13 +412,13 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
                 "Unable to decode the JSON response")
             raise
 
-    def put(self, path: str, document: Document, force_replace: bool = False) -> DocumentFamily:
+    def put(self, path: str, document: Document) -> DocumentFamily:
         from kodexa import KodexaPlatform
         try:
             logger.info(f"Putting document to path {path}")
 
             files = {"document": document.to_msgpack()}
-            data = {"path": path, "forceReplace": force_replace}
+            data = {"path": path}
             document_family_response = requests.post(
                 f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
                 headers={"x-access-token": KodexaPlatform.get_access_token()},
@@ -436,13 +436,13 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
                 "Unable to decode the JSON response")
             raise
 
-    def put_native(self, path: str, content, force_replace: bool = False) -> DocumentFamily:
+    def put_native(self, path: str, content) -> DocumentFamily:
         from kodexa import KodexaPlatform
         try:
             logger.info(f"Putting native content to path {path}")
 
             files = {"file": content}
-            data = {"path": path, "forceReplace": force_replace}
+            data = {"path": path}
             document_family_response = requests.post(
                 f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
                 headers={"x-access-token": KodexaPlatform.get_access_token()},
